@@ -124,7 +124,7 @@ gbf_am_config_value_copy (const GbfAmConfigValue *source)
 				    gbf_am_config_value_copy ((GbfAmConfigValue *)l->data);
 			    value->list = g_slist_prepend (value->list, new_value);
 		    }
-		    g_slist_reverse (value->list);
+		    value->list = g_slist_reverse (value->list);
 		    break;
 	    default:
 		    g_warning (_("Invalid GbfAmConfigValue type"));
